@@ -35,7 +35,6 @@ void args_parse()
 	int c, optidx;
 	struct option opts[] = {
 		{"line", 1, NULL, 'l'},
-//		{, , , },
 //		{, , , },
 		{NULL, 0, NULL, 0}
 	};
@@ -48,7 +47,7 @@ void args_parse()
 	for (;;)
 	{
 		c = getopt_long(args_number, args_arguments,
-				"l:", opts, &optidx);
+				"l:d", opts, &optidx);
 		
 		if ( c==-1 ) break;
 		
