@@ -20,6 +20,9 @@
 #include "netio.h"
 #include "proc_lcp3.h"
 #include "activities.h"
+#include "askname.h"
+
+#define SET_ENABLED(widget, state)	gtk_widget_set_sensitive(GTK_WIDGET(widget), state);
 
 void
 on_mn_file_activate                    (GtkMenuItem     *menuitem,
@@ -157,15 +160,15 @@ on_cl_lines_select_row                 (GtkCList        *clist,
                                         GdkEvent        *event,
                                         gpointer         user_data)
 {
-	struct tline * line = runtime_get_line(++row);
+	struct tline * line = runtime_get_line_clid(++row);
 	if ( runtime->selected_line == line ) return;
 	#ifdef DEBUG
 		g_print("selecting line %d '%s'\n", row, line->name);
 	#endif
 	runtime->selected_line = line;
-	netio_set_line_id(row);
-	config->default_line = row;
-	proc_status_tracker(runtime->client_status, row, line->status, line->channels, TRUE);
+	netio_set_line_id(line->num);
+	config->default_line = line->num;
+	proc_status_tracker(runtime->client_status, line->num, line->status, line->channels, TRUE);
 	cmd_send(CMD3_LINESEL, NULL, 0);
 	interface_propagate_line_data(line);
 }
@@ -311,8 +314,13 @@ on_mn_server_show_message_window_activate
                                         (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	wnd_messages = create_wnd_messages();
-	gtk_widget_show(wnd_messages);
+	if ( !wnd_messages )
+	{
+		wnd_messages = create_wnd_messages();
+		gtk_widget_show(wnd_messages);
+	}
+	else
+		gtk_window_activate_focus(wnd_messages);
 }
 
 void
@@ -669,3 +677,54 @@ on_ed_ahup_lines_changed               (GtkEditable     *editable,
 	if ( !line ) return;
 	interface_glob_line_2_wdg_autohangup(line->num);
 }
+
+void
+on_chk_enable_mysql_toggled            (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	gboolean state = gtk_toggle_button_get_active(togglebutton);
+	SET_ENABLED(wdg_config->ent_mysql_host, state)
+	SET_ENABLED(wdg_config->lb_mysql_host, state)
+	SET_ENABLED(wdg_config->ent_mysql_user, state)
+	SET_ENABLED(wdg_config->lb_mysql_user, state)
+	SET_ENABLED(wdg_config->ent_mysql_pass, state)
+	SET_ENABLED(wdg_config->lb_mysql_pass, state)
+	SET_ENABLED(wdg_config->ent_mysql_db, state)
+	SET_ENABLED(wdg_config->lb_mysql_db, state)
+	SET_ENABLED(wdg_config->chk_addrbook_ask, state)
+}
+
+void
+on_bt_asknum_cancel_clicked            (GtkButton       *button,
+                                        gpointer         user_data)
+{
+#if HAVE_LIBMYSQL
+	an_cancel();
+#endif
+}
+
+
+void
+on_bt_asknum_ok_clicked                (GtkButton       *button,
+                                        gpointer         user_data)
+{
+#if HAVE_LIBMYSQL
+	an_ok();
+#endif
+}
+
+
+void
+on_wnd_askname_unrealize               (GtkWidget       *widget,
+                                        gpointer         user_data)
+{
+	wdg_askname->realized = 0;
+}
+
+
+void
+on_wnd_askname_realize                 (GtkWidget       *widget,
+                                        gpointer         user_data)
+{
+	widgets_load_wdg_askname();
+}
