@@ -26,6 +26,14 @@ struct tConfig
 	gboolean wnd_activity_show;
 	int default_line;
 	gboolean start_minimized;
+	char * online_script;
+	char * offline_script;
+	gboolean mysql_enable;
+	char * mysql_host;
+	char * mysql_user;
+	char * mysql_pass;
+	char * mysql_db;
+	gboolean addrbook_ask;
 };
 
 extern struct tConfig *config;
