@@ -2,12 +2,16 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "../config.h"
+
 #include "proc_lcp3.h"
 #include "netio.h"
 #include "runtime.h"
 #include "cfg.h"
 #include "widgets.h"
 #include "interface_glob.h"
+#include "execute.h"
+#include "askname.h"
 
 #include <gtk/gtk.h>
 
@@ -39,8 +43,9 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 		return;
 	}
 	#ifdef DEBUG
-		g_print("got cmd %d\n", cmd->cmd);
+		g_print("processing cmd %s\n", lcp3_get_cmd_name(cmd->cmd));
 	#endif
+
 	// load pointers
 	infosize = get_lcp3_pack_size(cmd->cmd) - sizeof(struct t_lcp3_cmd);
 	if ( infosize )
@@ -54,7 +59,24 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 	info_tput = (void*)info;
 	info_status = (void*)info;
 	info_isdn = (void*)info;
+
+	#ifdef DEBUG
+		if ( cmd->cmd != CMD3_ACK )
+			g_print("got cmd %s\n", lcp3_get_cmd_name(cmd->cmd));
+		else
+			g_print("got cmd %s for %s\n", lcp3_get_cmd_name(cmd->cmd),
+					lcp3_get_cmd_name(info_ack->ackcmd));
+	#endif
+
 	// process status information
+	#ifdef PROTO_DEBUG
+		g_print("cmd->info_is_valid:      %d\n", cmd->info_is_valid);
+		g_print("cmd->client_stat         %d\n", cmd->client_stat);
+		g_print("cmd->line_id             %d\n", cmd->line_id);
+		g_print("cmd->line_stat           %d\n", cmd->line_stat);
+		g_print("cmd->line_channels       %d\n", cmd->line_channels);
+	#endif
+
 	if ( cmd->info_is_valid )
 	{
 		if ( (cmd->client_stat == CLT_OFFLINE) && (runtime->client_status == CLT_NOAUTH) )
@@ -67,6 +89,8 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wdg_conserver->chk_logged_in), TRUE);
 				gtk_label_set_text(wdg_conserver->lb_status, "donwloading lines...");
 			}
+			runtime->linecount = 0;
+			cmd_send(CMD3_GETALL, NULL, 0);
 			cmd_send(CMD3_LINESREQ, NULL, 0);
 		}
 		proc_status_tracker(cmd->client_stat, cmd->line_id, cmd->line_stat,
@@ -87,6 +111,7 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 			{
 				struct tline * newline = g_malloc(sizeof(struct tline));
 				gchar * row[8];
+				runtime->linecount++;
 				if ( !newline )
 				{
 					if ( wdg_conserver->realized )
@@ -125,14 +150,14 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 				cmd_send(CMD3_LINESEL, NULL, 0);
 				// selected it if it's the default line
 				newline->status = -1;
-				if ( info_line->total_lines == newline->num )
+				if ( info_line->total_lines == runtime->linecount )
 				{
 					runtime->selected_line = runtime_get_line(config->default_line);
 					netio_set_line_id(config->default_line);
 					if ( !cmd_send(CMD3_LINESEL, NULL, 0) )
 						g_print("selecting default line failed.\n");
 					gtk_clist_unselect_all(wdg_linemaster->cl_lines);
-					gtk_clist_select_row(wdg_linemaster->cl_lines, config->default_line-1, 0);
+					gtk_clist_select_row(wdg_linemaster->cl_lines, runtime_get_clid_lineid(config->default_line)-1, 0);
 					interface_propagate_line_data(runtime_get_line(config->default_line));
 					if ( wdg_conserver->realized )
 					{
@@ -141,7 +166,7 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 						// hmm... :)
 						gtk_widget_destroy(wnd_conserver);
 					}
-					cmd_send(CMD3_GETALL, NULL, 0);
+				//	cmd_send(CMD3_GETALL, NULL, 0);
 				}
 			}
 			break;
@@ -187,6 +212,9 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 			#endif
 			break;
 		case CMD3_ACK:
+			#ifdef DEBUG
+				g_print("CMD3_ACK is for %s\n", lcp3_get_cmd_name(info_ack->ackcmd));
+			#endif
 			break;
 		case CMD3_UNREG:
 			proc_lcp3_cleanup();
@@ -224,6 +252,12 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 				wdg_messages->msgs = g_list_append(wdg_messages->msgs, msg);
 				if ( wdg_messages->realized )
 					gtk_clist_append(wdg_messages->cl_messages, msg->row);
+				#if HAVE_LIBMYSQL
+					#ifdef ADDRBOOK_DEBUG
+						g_print("calling an_incoming_number(info_isdn->caller)...\n");
+					#endif
+					an_incoming_number(info_isdn->caller);
+				#endif
 			}
 			break;
 		default:
@@ -231,6 +265,9 @@ void proc_lcp3_process(gpointer data, gint sock, GdkInputCondition condition)
 				g_print("Received invalid command: %d\n", cmd->cmd);
 			#endif
 	}
+	#ifdef DEBUG
+		g_print("\n");
+	#endif
 	if ( cmd ) free(cmd);
 }
 
@@ -323,6 +360,7 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 #define WDG_ENABLE(wdg)	gtk_widget_set_sensitive(GTK_WIDGET(wdg), TRUE);
 #define WDG_DISABLE(wdg)	gtk_widget_set_sensitive(GTK_WIDGET(wdg), FALSE);
 	struct tline * pline = NULL;	
+	int row = runtime_get_clid_lineid(linenum)-1;
 	if ( (runtime->client_status != client) || force )
 	{
 		runtime->client_status = client;
@@ -357,6 +395,7 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 				WDG_DISABLE(wdg_linemaster->mn_line_offline)
 				WDG_DISABLE(wdg_linemaster->mn_server_connect)
 				WDG_DISABLE(wdg_linemaster->mn_line_isdnchannels)
+				execute(config->offline_script);
 				break;
 			case CLT_DIALING:
 				gtk_label_set_text(wdg_linemaster->lb_client_status, "dialing");
@@ -370,6 +409,7 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 				WDG_ENABLE(wdg_linemaster->mn_line_isdnchannels)
 				WDG_DISABLE(wdg_linemaster->mn_line_online)
 				WDG_ENABLE(wdg_linemaster->mn_line_offline)
+				execute(config->online_script);
 				break;
 			case CLT_CLOSING:
 				gtk_label_set_text(wdg_linemaster->lb_client_status, "closing");
@@ -415,12 +455,13 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 		}
 		pline->channels = channels;
 		pline->status = line;
-		if ( channels > 1 ) WDG_DISABLE(wdg_linemaster->mn_line_isdnchannels)
-		else WDG_ENABLE(wdg_linemaster->mn_line_isdnchannels)
+// With that you cannot switch off the second channel.
+//		if ( channels > 1 ) WDG_DISABLE(wdg_linemaster->mn_line_isdnchannels)
+//		else WDG_ENABLE(wdg_linemaster->mn_line_isdnchannels)
 		switch ( line )
 		{
 			case CST_DOWN:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_down);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_down);
 				if ( runtime->selected_line == pline )
 				{
 					WDG_ENABLE(wdg_linemaster->mn_line_online)
@@ -428,21 +469,21 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 				}
 				break;
 			case CST_DIALING:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_dialing);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_dialing);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_dialing);
 				}
 				break;
 			case CST_UP_SERVER:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_up_server);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_up_server);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_up_server);
 				}
 				break;
 			case CST_UP_USER:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_up_user);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_up_user);
 				if ( runtime->selected_line == pline )
 				{
 					WDG_DISABLE(wdg_linemaster->mn_line_online)
@@ -450,42 +491,42 @@ void proc_status_tracker(int client, int linenum, int line, int channels, gboole
 				}
 				break;
 			case CST_CLOSING:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_closing);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_closing);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_closing);
 				}
 				break;
 			case CST_CLOSE_ERROR:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_close_error);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_close_error);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_close_error);
 				}
 				break;
 			case CST_LOCKED_UP_CLT:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_locked_up_clt);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_locked_up_clt);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_locked_up_clt);
 				}
 				break;
 			case CST_LOCKED_DOWN:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_locked_down);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_locked_down);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_locked_down);
 				}
 				break;
 			case CST_LOCKED_UP_TIMED:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_locked_up_timed);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_locked_up_timed);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_locked_up_timed);
 				}
 				break;
 			default:
-				gtk_clist_set_text(wdg_linemaster->cl_lines, linenum-1, 2, msg_unknown);
+				gtk_clist_set_text(wdg_linemaster->cl_lines, row, 2, msg_unknown);
 				if ( runtime->selected_line == pline )
 				{
 					gtk_label_set_text(wdg_linemaster->lb_line_status, msg_unknown);
@@ -548,6 +589,7 @@ int proc_lcp3_init()
 	runtime->watchdog_barked = FALSE;
 	runtime->watchdog = time(NULL);
 	proc_lcp3_init_ok = TRUE;
+	runtime->client_status = CLT_NOAUTH;
 	return 1;
 }
 
