@@ -3,6 +3,8 @@
 
 #include <gtk/gtk.h>
 
+#include "widgets_cmn.h"
+
 void widgets_init();
 
 void widgets_load_wdg_activity();
@@ -17,6 +19,7 @@ struct twdg_activity
 {
 	GtkProgressBar * prg_up;
 	GtkProgressBar * prg_down;
+	GtkLabel * lb_msg;
 	gboolean realized;
 };
 extern struct twdg_activity * wdg_activity;
